from setuptools import setup

setup(
    name='absmartly',
    version='0.1.0',
    description='A Python SDK lib',
    url='https://github.com/absmartly/python-sdk',
    author='ABSmartly',
    author_email='pram@gmail.com',
    license='BSD 2-clause',
    packages=['sdk'],

    classifiers=[
        'Development Status :: 1 - Planning',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: BSD License',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
)
